@@ -92,7 +92,8 @@ static void handle_local_packet(void) {
         return;
     }
 
-    skaddr_u source_addr = {{0}};
+    skaddr_u source_addr;
+    memset(&source_addr, 0, sizeof(source_addr));
     socklen_t source_addrlen = sizeof(source_addr);
     ssize_t packet_len = recvfrom(s_bind_sockfd, s_packet_buf, DNS_PACKET_MAXSIZE, 0, &source_addr.sa, &source_addrlen);
 
@@ -109,7 +110,7 @@ static void handle_local_packet(void) {
     uint16_t qtype = dns_qtype(s_packet_buf, namelen);
     int ascii_namelen = dns_ascii_namelen(namelen);
     uint8_t name_tag = (ascii_namelen > 0 && g_dnl_nitems)
-        ? get_name_tag(s_name_buf, ascii_namelen) : NAME_TAG_NONE;
+        ? get_name_tag(s_name_buf, ascii_namelen) : g_default_tag;
 
     IF_VERBOSE {
         portno_t port = 0;
@@ -315,6 +316,7 @@ int main(int argc, char *argv[]) {
 
     dnl_init();
 
+    LOGI("default domain name tag: %s", nametag_val2name(g_default_tag));
     LOGI("%s reply without ip addr", g_noip_as_chnip ? "accept" : "filter");
     LOGI("dns query timeout: %d seconds", g_upstream_timeout_sec);
 
@@ -340,7 +342,8 @@ int main(int argc, char *argv[]) {
     LOGV("print the verbose running log");
 
     /* init ipset netlink socket */
-    ipset_init_nlsocket();
+    if (g_default_tag == NAME_TAG_NONE)
+        ipset_init_nlsocket();
 
     /* create listen socket */
     s_bind_sockfd = new_udp_socket(skaddr_family(&g_bind_skaddr));
